@@ -5,7 +5,6 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="26"/>
-        <location filename="../mainwindow.cpp" line="1215"/>
         <source>MX Network Assistant</source>
         <translation>MX Network Assistant</translation>
     </message>
@@ -129,7 +128,7 @@
     </message>
     <message>
         <location filename="../mainwindow.ui" line="609"/>
-        <location filename="../mainwindow.ui" line="726"/>
+        <location filename="../mainwindow.ui" line="725"/>
         <source>Target URL:</source>
         <translation>Στόχος URL:</translation>
     </message>
@@ -140,229 +139,239 @@
     </message>
     <message>
         <location filename="../mainwindow.ui" line="661"/>
-        <location filename="../mainwindow.ui" line="781"/>
+        <location filename="../mainwindow.ui" line="780"/>
         <source>Start</source>
         <translation>Ξεκινήστε</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="678"/>
-        <location filename="../mainwindow.ui" line="798"/>
+        <location filename="../mainwindow.ui" line="797"/>
         <source>Clear</source>
         <translation>Εκκαθάριση</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="692"/>
-        <location filename="../mainwindow.ui" line="812"/>
-        <location filename="../mainwindow.cpp" line="1221"/>
+        <location filename="../mainwindow.ui" line="811"/>
         <source>Cancel</source>
         <translation>Ακύρωση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="720"/>
+        <location filename="../mainwindow.ui" line="719"/>
         <source>Traceroute</source>
         <translation>Traceroute</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="736"/>
+        <location filename="../mainwindow.ui" line="735"/>
         <source>Hops</source>
         <translation>Hops</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="862"/>
+        <location filename="../mainwindow.ui" line="866"/>
         <source>About...</source>
         <translation>Περί</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="879"/>
+        <location filename="../mainwindow.ui" line="889"/>
         <source>Help</source>
         <translation>Βοήθεια </translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="941"/>
-        <location filename="../mainwindow.cpp" line="1237"/>
+        <location filename="../mainwindow.ui" line="957"/>
         <source>&amp;Close</source>
         <translation>&amp;Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="948"/>
+        <location filename="../mainwindow.ui" line="964"/>
         <source>Alt+C</source>
         <translation>Alt+C</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="153"/>
+        <location filename="../mainwindow.cpp" line="87"/>
         <source>IP address from router:</source>
         <translation>Διεύθυνση IP από το router:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="154"/>
+        <location filename="../mainwindow.cpp" line="88"/>
         <source>External IP address:</source>
         <translation>Εξωτερική διεύθυνση IP:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="291"/>
-        <location filename="../mainwindow.cpp" line="305"/>
-        <location filename="../mainwindow.cpp" line="319"/>
+        <location filename="../mainwindow.cpp" line="211"/>
+        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="239"/>
         <source>&amp;Copy</source>
         <translation>&amp;Αντιγραφή</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="293"/>
-        <location filename="../mainwindow.cpp" line="307"/>
-        <location filename="../mainwindow.cpp" line="321"/>
+        <location filename="../mainwindow.cpp" line="213"/>
+        <location filename="../mainwindow.cpp" line="227"/>
+        <location filename="../mainwindow.cpp" line="241"/>
         <source>Ctrl+C</source>
         <translation>Ctrl+C</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="294"/>
-        <location filename="../mainwindow.cpp" line="308"/>
-        <location filename="../mainwindow.cpp" line="322"/>
+        <location filename="../mainwindow.cpp" line="214"/>
+        <location filename="../mainwindow.cpp" line="228"/>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>Copy &amp;All</source>
         <translation>Αντιγραφή &amp;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="296"/>
-        <location filename="../mainwindow.cpp" line="310"/>
-        <location filename="../mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="216"/>
+        <location filename="../mainwindow.cpp" line="230"/>
+        <location filename="../mainwindow.cpp" line="244"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
-        <location filename="../mainwindow.cpp" line="383"/>
+        <location filename="../mainwindow.cpp" line="281"/>
+        <location filename="../mainwindow.cpp" line="303"/>
         <source>Traceroute not installed</source>
         <translation>Traceroute δεν έχει εγκατασταθεί</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="362"/>
+        <location filename="../mainwindow.cpp" line="282"/>
         <source>Traceroute is not installed, do you want to install it now?</source>
         <translation>Traceroute δεν έχει εγκατασταθεί, Θέλετε να το εγκαταστήσετε τώρα ;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="370"/>
+        <location filename="../mainwindow.cpp" line="290"/>
         <source>Traceroute hasn&apos;t been installed</source>
         <translation>Traceroute δεν έχει εγκατασταθεί</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="371"/>
+        <location filename="../mainwindow.cpp" line="291"/>
         <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
         <translation>Traceroute δεν μπορεί να εγκατασταθεί. Μπορεί αυτό να σημαίνει ότι χρησιμοποιείτε το LiveCD ή δεν μπορείτε να φτάσετε στο αποθετήριο λογισμικού,</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="384"/>
+        <location filename="../mainwindow.cpp" line="304"/>
         <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
         <translation>Traceroute δεν έχει εγκατασταθεί και δεν υπάρχει σύνδεση στο Internet, ώστε να μην μπορεί να εγκατασταθεί</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="391"/>
-        <location filename="../mainwindow.cpp" line="443"/>
+        <location filename="../mainwindow.cpp" line="311"/>
+        <location filename="../mainwindow.cpp" line="361"/>
         <source>No destination host</source>
         <translation>Δεν υπαρχει host προορισμού</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="392"/>
-        <location filename="../mainwindow.cpp" line="444"/>
+        <location filename="../mainwindow.cpp" line="312"/>
+        <location filename="../mainwindow.cpp" line="362"/>
         <source>Please fill in the destination host field</source>
         <translation>Παρακαλούμε συμπληρώστε το πεδίο host προορισμού</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="575"/>
+        <location filename="../mainwindow.cpp" line="493"/>
         <source>Loaded Drivers</source>
         <translation>Φορτωμένο Driver </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="585"/>
+        <location filename="../mainwindow.cpp" line="503"/>
         <source>Unloaded Drivers</source>
         <translation>Εκφορτωμένο Driver </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="601"/>
+        <location filename="../mainwindow.cpp" line="519"/>
         <source>Blacklisted Drivers</source>
         <translation>Προγραφόμενα Drivers</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="624"/>
+        <location filename="../mainwindow.cpp" line="542"/>
         <source>Blacklisted Broadcom Drivers</source>
         <translation>Προγραφόμενα Drivers του Broadcom</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1091"/>
+        <location filename="../mainwindow.cpp" line="1009"/>
         <source>enabled</source>
         <translation>ενεργοποιημένο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1094"/>
+        <location filename="../mainwindow.cpp" line="1012"/>
         <source>disabled</source>
         <translation>απενεργοποιημένο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1097"/>
+        <location filename="../mainwindow.cpp" line="1015"/>
         <source>WiFi hardware switch is off</source>
         <translation>Ο διακόπτης υλικού WiFi είναι απενεργοποιημένος</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1105"/>
+        <location filename="../mainwindow.cpp" line="1023"/>
         <source>Locate the Windows driver you want to add</source>
         <translation>Εντοπίστε το οδήγo των Windows που θέλετε να προσθέσετε</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1105"/>
+        <location filename="../mainwindow.cpp" line="1023"/>
         <source>Windows installation information file (*.inf)</source>
         <translation>Windows Installer αρχείο πληροφοριών (*.inf)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1137"/>
+        <location filename="../mainwindow.cpp" line="1055"/>
         <source>*.sys file not found</source>
         <translation>Το αρχείο *.sys  δε βρέθηκε</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1137"/>
+        <location filename="../mainwindow.cpp" line="1055"/>
         <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
         <translation>Τα αρχεία *.sys πρέπει να είναι στο ιδιο μερος το αρχειο * .inf. 1% δεν μπορεί να βρεθεί</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1148"/>
+        <location filename="../mainwindow.cpp" line="1066"/>
         <source>sys file reference not found</source>
         <translation>δε βρέθηκε το αρχείο sys</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1148"/>
+        <location filename="../mainwindow.cpp" line="1066"/>
         <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
         <translation>Το αρχείο sys για το οδήγo δεν μπορεί να προσδιοριστεί μετά ανάλυση του αρχείου .inf</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1167"/>
+        <location filename="../mainwindow.cpp" line="1085"/>
         <source>Ndiswrapper driver removed.</source>
         <translation>Το οδηγό Ndiswrapper έχει αφαιρεθεί.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1214"/>
-        <source>About MX Network Assistant</source>
-        <translation>Περί MX Network Assistant</translation>
+        <location filename="../mainwindow.cpp" line="1093"/>
+        <source>%1 Help</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1215"/>
+        <location filename="../mainwindow.cpp" line="1132"/>
+        <source>About %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1137"/>
+        <source>%1 License</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About MX Network Assistant</source>
+        <translation type="vanished">Περί MX Network Assistant</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1133"/>
         <source>Version: </source>
         <translation>Έκδοση:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1217"/>
+        <location filename="../mainwindow.cpp" line="1134"/>
         <source>Program for troubleshooting and configuring network for MX Linux</source>
         <translation>Eφαρμογή για την αντιμετώπιση προβλημάτων δικτύου και τη διαμόρφωση.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1218"/>
+        <location filename="../mainwindow.cpp" line="1136"/>
         <source>Copyright (c) MEPIS LLC and MX Linux</source>
         <translation>Copyright (c) MEPIS LLC and MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1219"/>
         <source>License</source>
-        <translation>Άδεια</translation>
+        <translation type="vanished">Άδεια</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1220"/>
         <source>Changelog</source>
-        <translation>Changelog</translation>
+        <translation type="vanished">Changelog</translation>
     </message>
 </context>
 <context>
@@ -373,106 +382,127 @@
         <translation>Πρέπει να τρέξετε αυτή την εφαρμογή ως Root.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="647"/>
+        <location filename="../mainwindow.cpp" line="565"/>
         <source>Ndiswrapper is not installed</source>
         <translation>Το Ndiswrapper δεν είναι εγκατεστημένο </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="656"/>
+        <location filename="../mainwindow.cpp" line="574"/>
         <source>driver installed</source>
         <translation>Το driver εγκαταστάθηκε</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="667"/>
+        <location filename="../mainwindow.cpp" line="585"/>
         <source> and in use by </source>
         <translation>και σε χρήση από</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="676"/>
+        <location filename="../mainwindow.cpp" line="594"/>
         <source>. Alternate driver: </source>
         <translation>Εναλλακτικό driver: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="768"/>
+        <location filename="../mainwindow.cpp" line="686"/>
         <source>Driver removed from blacklist</source>
         <translation>Αφαίρεση του driver από τη μαύρη λίστα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="769"/>
+        <location filename="../mainwindow.cpp" line="687"/>
         <source>Driver removed from blacklist.</source>
         <translation>Αφαίρεση του driver από τη μαύρη λίστα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="777"/>
-        <location filename="../mainwindow.cpp" line="778"/>
+        <location filename="../mainwindow.cpp" line="695"/>
+        <location filename="../mainwindow.cpp" line="696"/>
         <source>Module blacklisted</source>
         <translation>Module blacklisted</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="971"/>
+        <location filename="../mainwindow.cpp" line="889"/>
         <source>Installation successful</source>
         <translation>Εγκατάσταση με επιτυχια</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="975"/>
+        <location filename="../mainwindow.cpp" line="893"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
         <translation>Εντοπίστηκε σφάλμα, δεν θα μπορούσαν να καταρτίσουν πρόγραμμα οδήγησης ndiswrapper.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="980"/>
+        <location filename="../mainwindow.cpp" line="898"/>
         <source>Error detected, could not install ndiswrapper.</source>
         <translation>Εντοπίστηκε σφάλμα, δεν θα μπορούσε να εγκαταστήσετε το πακέτο ndiswrapper.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="992"/>
+        <location filename="../mainwindow.cpp" line="910"/>
         <source>Error encountered while removing Ndiswrapper</source>
         <translation>Προέκυψε σφάλμα κατά την αφαίρεση του ndiswrapper</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1050"/>
+        <location filename="../mainwindow.cpp" line="968"/>
         <source>Unblacklist Driver</source>
         <translation>Unblacklist Driver</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1055"/>
+        <location filename="../mainwindow.cpp" line="973"/>
         <source>Blacklist Driver</source>
         <translation>Προγραφή του Driver
  </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1196"/>
+        <location filename="../mainwindow.cpp" line="1115"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
         <translation>Δεν θα μπορούσε να ξεκλειδώσει τις συσκευές.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1198"/>
+        <location filename="../mainwindow.cpp" line="1117"/>
         <source>WiFi devices unlocked.</source>
         <translation>Συσκευές WiFi εχει ξεκλειδωθεί.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1271"/>
-        <location filename="../mainwindow.cpp" line="1272"/>
+        <location filename="../mainwindow.cpp" line="1162"/>
+        <location filename="../mainwindow.cpp" line="1163"/>
         <source>Driver loaded successfully</source>
         <translation>Το Driver φορτώθηκε επιτυχώς</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1290"/>
-        <location filename="../mainwindow.cpp" line="1291"/>
+        <location filename="../mainwindow.cpp" line="1181"/>
+        <location filename="../mainwindow.cpp" line="1182"/>
         <source>Driver unloaded successfully</source>
         <translation>Το Driver ξεφορτώθηκε επιτυχώς
 </translation>
     </message>
+    <message>
+        <location filename="../about.cpp" line="32"/>
+        <source>License</source>
+        <translation type="unfinished">Άδεια</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="33"/>
+        <location filename="../about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation type="unfinished">Changelog</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Ακύρωση</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished">&amp;Κλείσιμο</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="797"/>
+        <location filename="../mainwindow.cpp" line="715"/>
         <source>Could not load </source>
         <translation>Δεν ήταν δυνατή η φόρτωση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="833"/>
+        <location filename="../mainwindow.cpp" line="751"/>
         <source>Could not unload </source>
         <translation>Δεν ήταν δυνατή η ξεφόρτωση</translation>
     </message>
